pub struct Controller<'a> { /* private fields */ }Expand description
A reference to the endpoint of layers below (phy + eth + ip).
This is not really useful on its own but should instead be used either within a In or a
Raw. Some of the methods offered there will access the non-public members of this struct to
fulfill their task.
Implementations
Sourceimpl<'a> Controller<'a>
impl<'a> Controller<'a>
Sourcepub fn borrow_mut(&mut self) -> Controller<'_>
pub fn borrow_mut(&mut self) -> Controller<'_>
Proof to the compiler that we can shorten the lifetime arbitrarily.