Packet

Struct Packet 

pub struct Packet<'a, P: Payload> {
    pub control: Controller<'a>,
    pub packet: Packet<IpPacket<'a, P>>,
}
An incoming UDP packet.

Fields

control: Controller<'a>

A reference to the UDP endpoint state.

packet: Packet<IpPacket<'a, P>>

The valid packet inside the buffer.

Implementations

Source

impl<'a, P: Payload> Packet<'a, P>

pub fn reinit(self, init: Init) -> Result<Packet<'a, P>>
where P: PayloadMut,

Reinitialize the buffer with a packet generated by the library.

pub fn info(&self) -> &dyn Info

Get the hardware info for that packet.

pub fn deinit(self) -> RawPacket<'a, P>
where P: PayloadMut,

Unwrap the raw packet buffer.

This does not modify the contents of the buffer but it will drop the state derived from parsing the different packet layers.

pub fn send(self) -> Result<()>
where P: PayloadMut,

Called last after having initialized the payload.

Finalizes and queues the packet.