Handle

Struct Handle 

pub struct Handle(/* private fields */);
A newtype wrapper for the nic::Handle of Loopback.

This is only to ensure that future changes and additions can be done without relying on the internal representation.