Receiving and sending ARP messages.
Restricted to simple use of answering and sending arp based on the required addresses of the ip/ipv4 layer. You might not need to use this directly as it is embedded into the IP layer for its use in IPv4 addressing.
Its code could be more generic and might in the future be reused for other protocols.
Structs
- Controller
- A reference to the endpoint of layers below (phy + eth + ip).
- Endpoint
- The persistent data of an arp layer.
- InPacket
- An incoming packet.
- Neighbor
- A cached neighbor.
- Neighbor
Cache - A neighbor cache backed by a map.
- Neighbor
Table - A part of the neighbor table.
- OutPacket
- An outgoing packet as prepared by the arp layer.
- RawPacket
- A buffer into which a packet can be placed.
- Receiver
- An endpoint borrowed for receiving.
- Sender
- An arp endpoint for sending.
Enums
- Init
- Initializer for a packet.
- Neighbor
Answer - An answer to a neighbor cache lookup.
- Neighbor
Mapping - One mapped value of an entry in the neighbor cache.